"""Abstract for base API class."""
import os
from typing import Union, Any, Dict

from csp_cbc_auth.cbc.session import CBCSession
from psc_auth_integration.entities.auth_user_session import AuthUserSession
from requests import HTTPError

from cbc_content_reporting.logger import configure_logging

LOG = configure_logging(__name__)


class ReportingBaseClass:  # pylint: disable=too-few-public-methods
    """Represents an base API class object."""

    def __init__(self, session: Union[AuthUserSession, CBCSession]):
        self.session = session
        self.resources = os.path.join(os.path.dirname(os.path.realpath(__file__)), '../', 'resources')
        self.reporting_base_url = f'{session.gateway_url}/cds_reporting'

    def post(self, url: str, data: Any = None, json: Dict = None, **kwargs):
        response = self.session.post(url=url, data=data, json=json, **kwargs)
        LOG.info('POST: %s Status: %s', url, response.status_code)
        return response

    def get(self, url: str, **kwargs):
        """
        GET request with the current session and raise for status
        :param url: url to request
        :param kwargs: any additional kwargs for the request
        :return: Response object
        """
        response = self.session.get(url=url, **kwargs)
        LOG.info('GET: %s Status: %s', url, response.status_code)
        try:
            response.raise_for_status()
        except HTTPError as e:
            LOG.info('REQUEST KWARGS: %s', kwargs)
            raise e
        return response
